summaryrefslogtreecommitdiff
path: root/lib/rubygems/install_update_options.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/rubygems/install_update_options.rb')
-rw-r--r--lib/rubygems/install_update_options.rb13
1 files changed, 11 insertions, 2 deletions
diff --git a/lib/rubygems/install_update_options.rb b/lib/rubygems/install_update_options.rb
index ef1ad1edcb..54a3950b64 100644
--- a/lib/rubygems/install_update_options.rb
+++ b/lib/rubygems/install_update_options.rb
@@ -181,10 +181,19 @@ module Gem::InstallUpdateOptions
end
##
- # Default options for the gem install command.
+ # Default options for the gem install and update commands.
+
+ def install_update_options
+ {
+ :document => %w[ri],
+ }
+ end
+
+ ##
+ # Default description for the gem install and update commands.
def install_update_defaults_str
- '--document=rdoc,ri --wrappers'
+ '--document=ri'
end
end